#define Hg_Advect

       Subroutine advect

C**** *advect* - performs advection of properties in the ocean

C     e. maier-reimer      mpi hamburg      88/07/01.

C     purpose.
C     --------
C          *advect* performs advection algorithm in the ocean.
C                   advect takes most of computer time.
C                   with increasing approach to the stationary state,
C                   the iteration in advect converges faster, and the
C                   time consumption reduces.

C**   interface.
C     ----------
C          *call* *advect*

C     method.
C     -------
C          advection modeled by upstream formulation.
C     new concentration computed by solving very sparse matrix
C     using single-level scheme (e.g forsythe and moler, 1971;
C     diffusive transport: introduced by numerical advection
C     algorithm parallel to direction of tracer advection.
C     additional pure diffusive exchange with scalar points
C     at the corner of one grid point is performed (diffusion
C     coefficient is ''diff'').


C                principal plan view onto scalar points
C                --------- ---- ---- ---- ------ ------


C                                sno

C                          snw         sne
C                                sup
C                    swe         cm          sea
C                                slo
C                          ssw         sse

C                                sso



C                          x                      i=zonal index
C                         sno                     j=meridional index
C                        =cnw(i,j-2)              k=vertical (layer) ind
C                        =cn(i-1,j-2,k,iv)        v=PARAMETER index


C                 x                   x
C                snw                 sne
C               =cnw(i,j-1)         =cn(i,j-1,k,iv)
C               =cn(i-1,j-1,k,iv)

C                sup=cnu(i,j)=cn(i,j,k-1,iv)
C        x               cm= x ca(i,j,k,iv)      x
C       swe      slo=cnl(i,j)=cn(i,j,k+1,iv)    sea
C      =cnw(i,j)                               =cne(i,j)
C      =cn(i-1,j,k,iv)                         =cn(i+1,j+1,k,iv)


C                   x                   x
C                  ssw                 sse
C                 =cn(i,j+1,k,iv)     =cne(i,j+1)
C                                     =cn(i+1,j+1,k,iv)


C                              x
C                             sso
C                            =cne(i,j+2)
C                            =cn(i+1,j+2,k,iv)


C     externals.
C     ----------
C          none.

C     reference.
C     ----------

C        forsythe, g. e., and c. b. moler (1971)
C        computerverfahren fuer lineare algebraische systeme.
C        r. oldenbourg-verlag, muenchen, wien, 1971, 162 pp.

C        maier-reimer, e., and k. hasselmann (1987)
C        transport and storage of co2 in the ocean - an inorganic
C        ocean-circulation carbon cycle model.
C        climate dynamics, vol. 2, 63-90.

C        schendel, u. (1977)
C        sparse-matrizen.
C        r. oldenbourg-verlag, muenchen, wien, 1977, 150 pp.


C*     variable    type    purpose.
C      --------    ----    --------

C      *kitera*        INTEGER max. number of iterations to be performed
C                              for solving matrix
C      *dth*           REAL    timestep in seconds devided by two
C      *kiter*         INTEGER DO loop counter for iteration
C      *koo*           INTEGER index of upper ocean layer
C      *kuu*           INTEGER index of lower ocean layer
C      *wl*            REAL    w-component, lower layer, under center
C      *wu*            REAL    w-component, upper layer, above center
C      *uwe*           REAL    u-component, west of center
C      *uea*           REAL    u-component, east of center
C      *vsu*           REAL    v-component, south of center
C      *vno*           REAL    v-component, north of center
C      *swe*           REAL    actual concentration, west of center
C      *cm*            REAL    actual concentration, center
C      *sea*           REAL    actual concentration, east of center
C      *sso*           REAL    actual concentration, south of center
C      *sno*           REAL    actual concentration, north of center
C      *sup*           REAL    actual concentration, upper layer, above 
C      *slo*           REAL    actual concentration, lower layer, below 
C      *snw*           REAL    actual concentration, northwest of center
C      *sne*           REAL    actual concentration, northeast of center
C      *ssw*           REAL    actual concentration, southwest of center
C      *sse*           REAL    actual concentration, southeast of center
C      *crs*           REAL    term in czae with concentrations
C      *crsn*          REAL    term in czae with velocities
C      *chamax*        REAL    maximum of array chanma, used for criteri
C                              to STOP iteration in advection algorithm

C     -----------------------------------------------------------------
      INCLUDE 'parameter.include'
      INCLUDE 'common.horvel'
      INCLUDE 'common.wathic'
      INCLUDE 'common.chemis'
      INCLUDE 'common.biocon'
      INCLUDE 'common.topogr'
      INCLUDE 'common.production'
      INCLUDE 'common.thermo'
      INCLUDE 'common.ctrac'
      INCLUDE 'common.divers'
      INCLUDE 'common.caco3c'
      INCLUDE 'equivalence.include'
      DIMENSION swit(nv,ke)
      dimension hg_tot_surface_orig(ie,je,1,7:10)

      hg_tot_surface_orig(:,:,1,7:10) = cn(:,:,1,7:10)

      DO 1 iv=1,nv
      DO 1 k=1,ke
        swit(iv,k)=0.
    1 CONTINUE
      swit(3,1)=1.

C     -----------------------------------------------------------------
C*         1. set max. number of iterations to be performed
C             --- ---- ------ -- ---------- -- -- ---------

      kitera=100

C     -----------------------------------------------------------------
C*         2. set half of time step
C             --- ---- -- ---- ----

      dth=dt*0.5

C     -----------------------------------------------------------------
C*         3. begin of iteration (advection algorthm)
C             ----- -- --------- ---------- ---------

C*         3.1 PARAMETER loop

C$ DOACROSS local ( koo, kuu, czae, cnen, convl, cnu, cnl, cnw, 
C$& uwes, vwes, ddzl, dduw, ddzr, cne, wl, wu, uwe, uea, vsu, vno, 
C$& swe, cm, sm, sea, sso, sno, sup, slo, snw, sne, ssw, sse, crs, 
C$& crsn, chanma, chamax, kiter,i,j)




#ifdef Hg_Advect
      DO 200 iv=1, 10    !  nv
#else
      DO 200 iv=1, 6    !  nv
#endif
c         IF (iv .EQ. 5) GO TO 200
c         IF (iv .EQ. 6) GO TO 200
c         IF (iv .GE. 9) GO TO 200

C*         3.2 iteration loop for all grid points of one
C              PARAMETER
      DO 2107 kiter=1,kitera

C*         3.3 set number of iterations to be performed
C              for each PARAMETER iv
      niter(iv)=kiter

C*         3.4 initiate maximum of difference in concentration
C              between two subsequent iteration steps
      chamax=zero

C*         3.5 layer loop
      kStart = 1
c      if( iv .GE. 7 ) then
c         kStart = 2
c      endif
      DO 21 k=kStart,ke

C*         3.6 set indices of upper and lower layer
      koo=max0(k-1,1)
      kuu=min0(k+1,ke)

C*         3.7 prepare dummy variables for upstream scheme
C     DO 2111 j=jl1,jle
C***new in crun61b
      DO 2111 j=1,je
      DO 2111 i=1,ie
      czae(i,j)=0.
      cnen(i,j)=0.
      convl(i,j)=zero
      cnu(i,j)=cn(i,j,koo,iv)
      cnl(i,j)=cn(i,j,kuu,iv)
      IF(i .GT. 1) THEN
         cnw(i,j)=cn(i-1,j,k,iv)
         uwes(i,j)=u(i-1,j,k)
         vwes(i,j)=v(i-1,j,k)
         ddzl(i,j)=ddz(i-1,j,k)
         dduw(i,j)=ddu(i-1,j,k)
      ENDIF
      IF( i .LT. ie) THEN
         ddzr(i,j)=ddz(i+1,j,k)
         cne(i,j)=cn(i+1,j,k,iv)
      ENDIF
2111  CONTINUE
      IF(k.LT.ke) then
C     DO 2112 j=jl1,jle
C***new in crun61b
      DO 2112 j=1,je
      DO 2112 i=1,ie
      convl(i,j)=convad(i,j,k+1)
2112  CONTINUE
      ENDIF
C     DO 2114 j=jl1,jle
C***new in crun61b
      DO 2114 j=1,je
      cnw(1,j)=cn(ie,j,k,iv)
      cne(ie,j)=cn(1,j,k,iv)
      uwes(1,j)=u(ie,j,k)
      vwes(1,j)=v(ie,j,k)
      ddzl(1,j)=ddz(ie,j,k)
      dduw(1,j)=ddu(ie,j,k)
      ddzr(ie,j)=ddz(1,j,k)
2114  CONTINUE

C     -----------------------------------------------------------------
C*         4. upstream scheme
C             -------- ------
      DO 222 j=jl1,jle
C     jstart=jl1+1
C     jSTOP=jle-2
C     DO 222 j=jstart,jSTOP
      DO 222 i=1,ie
      wl=w(i,j,k+1)*dlll(i,j)
      wu=w(i,j,k)*dlll(i,j)
      uwe=uwes(i,j)*dduw(i,j)
      uea=u(i,j,k)*ddu(i,j,k)
      vsu=v(i,j+1,k)*ddu(i,j+1,k)*dlll(i,j+1)*dpin
      vno=vwes(i,j-1)*dduw(i,j-1)*dlll(i,j-1)*dpin
      swe=cnw(i,j)
      cm=ca(i,j,k,iv)
      sm=cn(i,j,k,iv)
      sea=cne(i,j)
      sso=cne(i,j+2)
      sno=cnw(i,j-2)
      sup=cnu(i,j)
      slo=cnl(i,j)
      snw=cnw(i,j-1)
      sne=cn(i,j-1,k,iv)
      ssw=cn(i,j+1,k,iv)
      sse=cne(i,j+1)
      crs=cm*ddz(i,j,k)*dlll(i,j)+cm*epsma
     .  +diff*ddz(i,j,k)*(ddzl(i,j-1)*snw+ddz(i,j-1,k)*sne
     .  +ddz(i,j+1,k)*ssw+ddzr(i,j+1)*sse)
      crsn=dth*((uwe+abs(uwe))*swe+(abs(uea)-uea)*sea)
     .  +dth*((wl+abs(wl))*slo+(abs(wu)-wu)*sup)
     .  +dth*((vsu+abs(vsu))*sso+(abs(vno)-vno)*sno)
     .  +convad(i,j,k)*sup+convl(i,j)*slo
      czae(i,j)=crs+crsn
      cnen(i,j)=ddz(i,j,k)*dlll(i,j)
     .    *(1.+prlat(i,j)*rwat(i,j)*swit(iv,k)*sm/(conc0+sm))
     .  +dth*(-uwe+abs(uwe)
     .  +abs(uea)+uea)+epsma
     .  +diff*ddz(i,j,k)*(ddzl(i,j-1)+ddzr(i,j+1)+ddz(i,j-1,k)
     .  +ddz(i,j+1,k))
     .  +dth*(vno+abs(vsu)+abs(vno)-vsu-wl+abs(wl)+abs(wu)+wu)
     .  +convad(i,j,k)+convl(i,j)
C     IF(i.EQ.45.AND.j.EQ.3.AND.k.EQ.8.AND.iv.EQ.5)then
C     print*,'***loch upstream***'
C     print*,'i j k ',i,j,k
C     print*,'dzdl(i,j,k)= ',dzdl(i,j,k)
C     print*,'diff= ',diff
C     print*,'ddz(i,j,k) ',ddz(i,j,k)
C     print*,'dth= ',dth
C     print*,' '
C     print*,'crs= ',crs
C     print*,'crsn= ',crsn
C     print*,'czae(i,j)= ',czae(i,j)
C     print*,'cnen(i,j)= ',cnen(i,j)
C     print*,' '
C     print*,'convad(i,j,k)= ',convad(i,j,k)
C     print*,'convl(i,j)= ',convl(i,j)
C     print*,' '
C     print*,'cm= ',cm
C     print*,'sm= ',sm
C     print*,' '
C     print*,'sup= ',sup
C     print*,'wu= ',wu
C     print*,'w(i,j,k)= ',w(i,j,k)
C     print*,'dlll(i,j)= ',dlll(i,j)
C     print*,' '
C     print*,'slo= ',slo
C     print*,'wl= ',wl
C     print*,'w(i,j,k+1)= ',w(i,j,k+1)
C     print*,'dlll(i,j)= ',dlll(i,j)
C     print*,' '
C     print*,'sno= ',sno
C     print*,'vno= ',vno
C     print*,'vwes(i,j-1)= ',vwes(i,j-1)
C     print*,'dduw(i,j-1)= ',dduw(i,j-1)
C     print*,'dlll(i,j-1)= ',dlll(i,j-1)
C     print*,'dpin= ',dpin
C     print*,' '
C     print*,'sso= ',sso
C     print*,'vsu= ',vsu
C     print*,'v(i,j+1,k)= ',v(i,j+1,k)
C     print*,'ddu(i,j+1,k)= ',ddu(i,j+1,k)
C     print*,'dlll(i,j+1)= ',dlll(i,j+1)
C     print*,'dpin= ',dpin
C     print*,' '
C     print*,'swe= ',swe
C     print*,'uwe= ',uwe
C     print*,'uwes(i,j)= ',uwes(i,j)
C     print*,'dduw(i,j)= ',dduw(i,j)
C     print*,' '
C     print*,'sea= ',sea
C     print*,'uea= ',uea
C     print*,'u(i,j,k)= ',u(i,j,k)
C     print*,'ddu(i,j,k)= ',ddu(i,j,k)
C     print*,' '
C     print*,'snw= ',snw
C     print*,'ddzl(i,j-1)= ',ddzl(i,j-1)
C     print*,' '
C     print*,'sne= ',sne
C     print*,'ddz(i,j-1,k)= ',ddz(i,j-1,k)
C     print*,' '
C     print*,'ssw= ',ssw
C     print*,'ddz(i,j+1,k)= ',ddz(i,j+1,k)
C     print*,' '
C     print*,'sse= ',sse
C     print*,'ddzr(i,j+1)= ',ddzr(i,j+1)
C     print*,' '
C     print*,'***ende loch***************'
C     ENDIF
C     tt1=czae(i,j)
C     tt2=cnen(i,j)
222   CONTINUE

C     -----------------------------------------------------------------
C*         5. evaluation of tracer concentration after iteration step
C             ---------- -- ------ ------------- ----- --------- ----
      DO 444 j=jl1,jle
      DO 444 i=1,ie
      convl(i,j)=cn(i,j,k,iv)

C*         5.1 resulting concentration of iteration step
c      if( k .GT. 1 ) then
         cn(i,j,k,iv)=czae(i,j)/cnen(i,j)
c      endif

C*         5.2 calculate absolute value of concentration difference
C              between two subsequent iteration steps (arrays
C              cnw and convl are used as storage arrays for reasons
C              of ecocnomics
      cnw(i,j)=cn(i,j,k,iv)-convl(i,j)
      convl(i,j)=abs(cnw(i,j))
444   CONTINUE

C*         5.3 determine maximum value of concentration differences
C              between two subsequent iteration steps for each layer
      chanma(k)=zero
      DO 445 j=1,je
      DO 445 i=1,ie
      chanma(k)=amax1(chanma(k),convl(i,j))
445   CONTINUE

C*         5.4 [o2] is set to saturation value in the surface layer
C              and to arithmetic mean of saturation value and actual
C              concentration of subsurface layer in subsurface layer
      if( iv .GE. 7 .AND. iv .LE. 10 .AND. k .LE. 2 ) then
         cn(i,j,1,iv) = hg_tot_surface_orig(i,j,1,iv)
         cn(i,j,2,iv) = 0.25*(cn(i,j,1,iv)+3.*cn(i,j,2,iv))
      endif

      IF(iv.EQ.4.AND.k.le.2) then
      DO 446 j=1,je
      DO 446 i=1,ie
        cn(i,j,1,iv)=chemc(i,j,7)
        cn(i,j,2,iv)=0.25*(cn(i,j,1,iv)+3.*cn(i,j,2,iv))
446   CONTINUE
      ENDIF
21    CONTINUE
1294  CONTINUE

C*         5.5 the difference between two subsequent iteration
C              steps is disregarded for [o2] in the upper two
C              layers (k=1,2) because for the surface layer the
C              saturation value, and for the second value the
C              arithmetic mean between actual concentration and
C              saturation value are used
      IF(iv.EQ.4)then
      chanma(1)=0.
      chanma(2)=0.
      ENDIF

C*         5.6 determine maximum value of concentration differences
C              between two subsequent iteration steps for whole
C              water column
      DO 2121 k=1,ke
      chamax=amax1(chamax,chanma(k))
2121  CONTINUE

C*         5.7 if maximum value of concentration differences
C              between two subsequent iteration steps (whole water
C              column is less than the max. value allowed (scrit),
C              the iteration is STOPped

c      write(6,*) iv, kiter, chamax


       IF(chamax.LT.scrit(iv)) GO TO 2108
2107  CONTINUE

C*         5.8 END of iteration
2108  CONTINUE

c         write(6,*) iv, kiter, chamax, scrit(iv)

C     WRITE(41,'(''***in advect vor korrektur'')')
C     DO 5835 j=1,je
C     DO 5835 i=1,je
C       WRITE(41,'(''***in advect vor korrektur '',
C    1            ''sco212('',i2,'','',i2,'',1)= '',e12.6)')
C    1   i,j,sco212(i,j,1)
C5835 CONTINUE
C ***neu begin
C     -----------------------------------------------------------------
C*         x. begin of calculation of concentrations at new time step
C             with new fluxes
C             ---- --- ----------- -- -------------- -- --- ---- ----


C*         x.1 layer loop
      DO 31 k=1,ke

C*         x.2 set indices of upper and lower layer
      koo=max0(k-1,1)
      kuu=min0(k+1,ke)

C*         x.3 prepare dummy variables for upstream scheme
C     DO 3111 j=jl1,jle
C***new in crun61b
      DO 3111 j=1,je
      DO 3111 i=1,ie
      czae(i,j)=0.
      cnen(i,j)=0.
      convl(i,j)=zero
      cnu(i,j)=cn(i,j,koo,iv)
      cnl(i,j)=cn(i,j,kuu,iv)
      IF(i .GT. 1) THEN
         cnw(i,j)=cn(i-1,j,k,iv)
         uwes(i,j)=u(i-1,j,k)
         vwes(i,j)=v(i-1,j,k)
         ddzl(i,j)=ddz(i-1,j,k)
         dduw(i,j)=ddu(i-1,j,k)
      ENDIF
      IF( i .LT. ie) THEN
         cne(i,j)=cn(i+1,j,k,iv)
         ddzr(i,j)=ddz(i+1,j,k)
      ENDIF
3111  CONTINUE
      IF(k.LT.ke) then
C     DO 3112 j=jl1,jle
C***new in crun61b
      DO 3112 j=1,je
      DO 3112 i=1,ie
      convl(i,j)=convad(i,j,k+1)
3112  CONTINUE
      ENDIF
C     DO 3114 j=jl1,jle
C***new in crun61b
      DO 3114 j=1,je
      cnw(1,j)=cn(ie,j,k,iv)
      cne(ie,j)=cn(1,j,k,iv)
      uwes(1,j)=u(ie,j,k)
      vwes(1,j)=v(ie,j,k)
      ddzl(1,j)=ddz(ie,j,k)
      dduw(1,j)=ddu(ie,j,k)
      ddzr(ie,j)=ddz(1,j,k)
3114  CONTINUE

C     -----------------------------------------------------------------
C*         x. upstream scheme
C             -------- ------
C     WRITE(41,'(''attent.GT.0.01 i j k wu wl uea uwe vno vsu '',
C    *  '' dduw(i,j),ddu(i,j,k),dduw(i,j-1),ddu(i,j+1,k) '')')
      DO 322 j=jl1,jle
C     jstart=jl1+1
C     jSTOP=jle-2
C     DO 322 j=jstart,jSTOP
      DO 322 i=1,ie
      wl=w(i,j,k+1)*dlll(i,j)
      wu=w(i,j,k)*dlll(i,j)
      uwe=uwes(i,j)*dduw(i,j)
      uea=u(i,j,k)*ddu(i,j,k)
      vsu=v(i,j+1,k)*ddu(i,j+1,k)*dlll(i,j+1)*dpin
      vno=vwes(i,j-1)*dduw(i,j-1)*dlll(i,j-1)*dpin
      swe=cnw(i,j)
      cm=ca(i,j,k,iv)
      sm=cn(i,j,k,iv)
      sea=cne(i,j)
      sso=cne(i,j+2)
      sno=cnw(i,j-2)
      sup=cnu(i,j)
      slo=cnl(i,j)
      snw=cnw(i,j-1)
      sne=cn(i,j-1,k,iv)
      ssw=cn(i,j+1,k,iv)
      sse=cne(i,j+1)
C     fludif=wu-wl+uea-uwe+vno-vsu
C     flusum=abs(wu)+abs(wl)+abs(uea)+abs(uwe)
C    *    +abs(vno)+abs(vsu)
C     eps=1.e-22
C     attent=abs(fludif/(flusum+eps))
C     IF(attent.GT.0.01)
C    * WRITE(41,'(3i3,6(1x,f10.4),2x,4(1x,e9.3))')
C    *      i,j,k,wu,wl,uea,uwe,vno,vsu,
C    *      dduw(i,j),ddu(i,j,k),dduw(i,j-1),ddu(i,j+1,k)
      crs=
     .  +diff*ddz(i,j,k)*(ddzl(i,j-1)*snw+ddz(i,j-1,k)*sne
     .  +ddz(i,j+1,k)*ssw+ddzr(i,j+1)*sse)
      crsn=dth*((uwe+abs(uwe))*swe+(abs(uea)-uea)*sea)
     .  +dth*((wl+abs(wl))*slo+(abs(wu)-wu)*sup)
     .  +dth*((vsu+abs(vsu))*sso+(abs(vno)-vno)*sno)
     .  +convad(i,j,k)*sup+convl(i,j)*slo
      czae(i,j)=crs+crsn
C     cnen(i,j)=ddz(i,j,k)*dlll(i,j)
C    1  *(1.+prlat(i,j)*rwat(i,j)*swit(iv,k)*sm/(conc0+sm))
      cnen(i,j)=
     .  +dth*(-uwe+abs(uwe)
     .  +abs(uea)+uea)+epsma
     .  +diff*ddz(i,j,k)*(ddzl(i,j-1)+ddzr(i,j+1)+ddz(i,j-1,k)
     .  +ddz(i,j+1,k))
     .  +dth*(vno+abs(vsu)+abs(vno)-vsu-wl+abs(wl)+abs(wu)+wu)
     .  +convad(i,j,k)+convl(i,j)

C            45 3 8 5
C     IF(i.EQ.45.AND.j.EQ.3.AND.k.EQ.8.AND.iv.EQ.5)then
C     print*,'***loch ca fluxcorr*** loop 544'
C     print*,'i j k iv  ',i,j,k,iv
C     print*,' '
C     print*,'ca(i,j,k,iv)= ',ca(i,j,k,iv)
C     print*,'cm= ',cm
C     print*,'czae(i,j)= ',czae(i,j)
C     print*,'cnen(i,j)= ',cnen(i,j)
C     didi1=cnen(i,j)*sm
C     didi2=czae(i,j)-cnen(i,j)*sm
C     didi3=(czae(i,j)-cnen(i,j)*sm)/(dzdl(i,j,k)+epsma)
C     print*,'didi1=cnen(i,j)*sm=',didi1
C     print*,'didi2=czae(i,j)-cnen(i,j)*sm= ',didi2
C     print*,
C    * 'didi3=(czae(i,j)-cnen(i,j)*sm)/(dzdl(i,j,k)+epsma)= ',
C    *  didi3
C     didi4=crs+crsn
C     print*,'didi4=crs+crsn= ',didi4
C     print*,'sm= ',sm
C     print*,'dzdl(i,j,k)= ',dzdl(i,j,k)
C     print*,'epsma= ',epsma
C     print*,' '
C     print*,'diff= ',diff
C     print*,'ddz(i,j,k) ',ddz(i,j,k)
C     print*,'dth= ',dth
C     print*,' '
C     print*,'crs= ',crs
C     print*,'crsn= ',crsn
C     print*,'czae(i,j)= ',czae(i,j)
C     print*,'cnen(i,j)= ',cnen(i,j)
C     print*,' '
C     print*,'convad(i,j,k)= ',convad(i,j,k)
C     print*,'convl(i,j)= ',convl(i,j)
C     print*,' '
C     print*,'cm= ',cm
C     print*,'sm= ',sm
C     print*,' '
C     print*,'sup= ',sup
C     print*,'wu= ',wu
C     print*,'w(i,j,k)= ',w(i,j,k)
C     print*,'dlll(i,j)= ',dlll(i,j)
C     print*,' '
C     print*,'slo= ',slo
C     print*,'wl= ',wl
C     print*,'w(i,j,k+1)= ',w(i,j,k+1)
C     print*,'dlll(i,j)= ',dlll(i,j)
C     print*,' '
C     print*,'sno= ',sno
C     print*,'vno= ',vno
C     print*,'vwes(i,j-1)= ',vwes(i,j-1)
C     print*,'dduw(i,j-1)= ',dduw(i,j-1)
C     print*,'dlll(i,j-1)= ',dlll(i,j-1)
C     print*,'dpin= ',dpin
C     print*,' '
C     print*,'sso= ',sso
C     print*,'vsu= ',vsu
C     print*,'v(i,j+1,k)= ',v(i,j+1,k)
C     print*,'ddu(i,j+1,k)= ',ddu(i,j+1,k)
C     print*,'dlll(i,j+1)= ',dlll(i,j+1)
C     print*,'dpin= ',dpin
C     print*,' '
C     print*,'swe= ',swe
C     print*,'uwe= ',uwe
C     print*,'uwes(i,j)= ',uwes(i,j)
C     print*,'dduw(i,j)= ',dduw(i,j)
C     print*,' '
C     print*,'sea= ',sea
C     print*,'uea= ',uea
C     print*,'u(i,j,k)= ',u(i,j,k)
C     print*,'ddu(i,j,k)= ',ddu(i,j,k)
C     print*,' '
C     print*,'snw= ',snw
C     print*,'ddzl(i,j-1)= ',ddzl(i,j-1)
C     print*,' '
C     print*,'sne= ',sne
C     print*,'ddz(i,j-1,k)= ',ddz(i,j-1,k)
C     print*,' '
C     print*,'ssw= ',ssw
C     print*,'ddz(i,j+1,k)= ',ddz(i,j+1,k)
C     print*,' '
C     print*,'sse= ',sse
C     print*,'ddzr(i,j+1)= ',ddzr(i,j+1)
C     print*,' '
C     print*,'***ende loch***************'
C     ENDIF

C     tt1=czae(i,j)
C     tt2=cnen(i,j)
322   CONTINUE

C     -----------------------------------------------------------------
C*         5. evaluation of tracer concentration after calculation
C             of new concentrations with fluxes
C             -- --- -------------- ---- ------- ----- -----------
      IF(iv.EQ.4)then
        DO 543 j=jl1,jle
        DO 543 i=1,ie
          ca(i,j,k,iv)=cn(i,j,k,iv)
  543   CONTINUE
      ELSE
        DO 544 j=jl1,jle
        DO 544 i=1,ie
        convl(i,j)=cn(i,j,k,iv)
        cm=ca(i,j,k,iv)
        sm=cn(i,j,k,iv)

C*         5.1 resulting concentration of iteration step
        ca(i,j,k,iv)=cm+(czae(i,j)-cnen(i,j)*sm)/(dzdl(i,j,k)+epsma)
C     ca(i,j,k,iv)=ca(i,j,k,iv)+(czae(i,j)-cnen(i,j)
C   1*cn(i,j,k,iv))/(dzdl(i,j,k)+epsma)
  544   CONTINUE
      ENDIF

C*         5.4 [o2] is set to saturation value in the surface layer
C              and to arithmetic mean of saturation value and actual
C              concentration of subsurface layer in subsurface layer
      IF(iv.EQ.4.AND.k.le.2) then
      DO 546 j=1,je
      DO 546 i=1,ie
        ca(i,j,1,4)=chemc(i,j,7)
        ca(i,j,2,4)=0.25*(ca(i,j,1,4)+3.*ca(i,j,2,4))
546   CONTINUE
      ENDIF
31    CONTINUE
C ***neu END

C     -----------------------------------------------------------------
C*         5a.  adjust dissolved o2 during convection
C               ------ --------- -- ------ ----------
C ***new in crun049 89/02/14 begin
C     DO 202k=ke,2,-1
C     DO 202 j=jl1,jle
C     DO 202 i=1,ie
C       IF(convad(i,j,k).GT.0.01)
C    *            oxygen(i,j,k)=oxygen(i,j,k-1)
C 202 CONTINUE
C ***new in crun049 89/02/14 END

C     -----------------------------------------------------------------
C*         6.  redefinition new value->old value for next time step
C              ------------ --- ---------- ----- --- ---- ---- ----
C     IF(iv.EQ.6)
C    *  print*,'calc12 chanma ',chanma



200   CONTINUE
      DO 203 j=1,je
      DO 203 i=1,ie
        conc=cn(i,j,1,3)
        conc0 = 2.E-6
c        conc0 = 5.E-7
        prorca(i,j)=prlat(i,j)*rwat(i,j)
c     $       * 3.
     *       * conc / 2.
     *       * conc/(conc+conc0)

        ca(i,j,1,3)=ca(i,j,1,3)-prorca(i,j)
  203 CONTINUE
C      IF(ifulbi.EQ.1)
c      print*,'iterations ', niter
      RETURN
      END




