      SUBROUTINE biology

C**** *biosof* - production of biogenic matter and its distribution

C     e. maier-reimer      mpi hamburg      88/07/01.

C     purpose.
C     --------
C          *biosof* models production of biogenic matter (poc ''soft
C                   tissue'' and caco3 particles ''hard parts'')
C                   and its distribution in water column

C**   interface.
C     ----------
C          *call* *biosof*

C     method.
C     -------
C          in the surface layer poc is produced according to
C     nurtrients available and growth conditions. nutrient uptake
C     kinetics follow michaelis-menton formulation. proportional
C     to the amount of organic matter, caco3 hard parts are produced.
C     the total particle amount produced, is distributed in the water
C     column below the surface layer.

C     externals.
C     ----------
C          none.

C     reference.
C     ----------

C          bacastow, r., and e. maier-reimer (1985)
C          circulation model of the ocean carbon cycle.
C          1. description of the model, pp. 224-232.
C          2. comparison of the model results with observational DATA,
C          pp. 233-240.
C          in: "atmospheric carbon dioxide - its sources, sinks, and
C          global transport", kandersteg, 2 to 6 september 1985,
C          commission on atmospheric chemistry and global pollution,
C          international association of meteorology and atmospheric phys

C          dugdale. r.c. (1967)
C          nutrient limitation in the sea: dynamics, identification
C          and significance.
C          limnology and oceanography, vol.12, 685-695.

C          parsons, t.r., and m. takahashi (1973)
C          biological oceanographic processes.
C          pergamon press, 186 pp.


C*     variable        type    purpose.
C      --------        ----    --------

C      *pr14pr(ie,je)* REAL    actual ratio [sum((14c)o2)]/[sum((12c)o2)
C                              in surface layer
C      *pr13pr(ie,je)* REAL    actual ratio [sum((13c)o2)]/[sum((12c)o2)
C                              in surface layer
C      *ke1*           INTEGER max. index in vertical direction minus
C                              minus 1
C      *conc*          REAL    [po4] in surface layer, dummy variable
C      *produc*        REAL    production of carbon in soft tissue accor
C                              to [po4] and other PARAMETERs (cf. prlat)
C                              uppermost layer using michalis menton kin
C                              dummy variable
C      *gim*           REAL    conversion factor moles carbon -> g for
C                              integration of total primary production
C                              over the whole surface layer; to
C                              account for overlapping of grid point box
C                              gim is diveded by 2 (.006 instead of .012
C                              see below)
C      *topro*         REAL    total global annual primary production
C                              [g/year]

C     -----------------------------------------------------------------
      INCLUDE 'parameter.include'
      INCLUDE 'common.horvel'
      INCLUDE 'common.wathic'
      INCLUDE 'common.chemis'
      INCLUDE 'common.biocon'
      INCLUDE 'common.topogr'
      INCLUDE 'common.production'
      INCLUDE 'common.thermo'
      INCLUDE 'common.ctrac'
      INCLUDE 'common.divers'
      INCLUDE 'common.caco3c'
      INCLUDE 'equivalence.include'
c       moved to common.topogr
c      DIMENSION pr13pr(ie,je),pr14pr(ie,je)

C     -----------------------------------------------------------------
C*         1. set half precision constants
C             --- ---- --------- ---------

      zero=0.
      one=1.
      two=2.

C     -----------------------------------------------------------------
C*         2. calculate production of soft tissue and related caco3
C             hard parts using michaelis menton kinetics (cf. dugdale,
C             1967; parsons and takahashi, 1973)
C             ----- ------- --- ---------- ------------- ---- --------

      DO 1 j=jl1,jle
      DO 1 i=1,ie

C*         2.1  actual [po4---] concentration [mole/l]
      conc=phosph(i,j,1)

C*         2.2  primary production of poc (soft tissue) using
C               michaelis-menton nutrient uptake kinetics [mole/l]
C     produc=rwat(i,j)*prlat(i,j)*conc**2/(conc+conc0)
C     prorca(i,j)=produc

C*         2.3  poc production related biogenic caco3 particle
C               production [mole/l]
C     expofa=EXP(0.4*tem(i,j,1))
C     calred=expofa/(100.+expofa)
      expofa=EXP(1.*(tem(i,j,1)-3.5))
      calred=expofa/(5.+expofa)
C     print*,'calred  ',calred
      prcaca(i,j)=prorca(i,j)*caco3r*calred
c     **********************************************************
c     special shit for deMenocal
c     **********************************************************
c      if( ibasin(i,j) .EQ. 1 .AND. prorca(i,j) .GT. 0.) then
c         write(6,*) i,j, ibasin(i,j), prorca(i,j) 
c         prcaca(i,j) = 0.5 * prcaca(i,j)
c      endif
c     *********************************************************

C     prcaca(i,j)=prorca(i,j)*caco3r

C*         2.4  total production (poc + caco3) [moles c]
      prodt(i,j)=prorca(i,j)+prcaca(i,j)
1     CONTINUE

C     -----------------------------------------------------------------
C*         3. initiate surface layer c13/c12, c14/c12 total co2 ratios
C             of inorg. c taken up by planktonic organisms
C             -- ------ - ----- -- -- ---------- ---------- --- ------

      DO 2 j=jl1,jle
      DO 2 i=1,ie
      pr13pr(i,j)=zero
      pr14pr(i,j)=zero
2     CONTINUE

C     -----------------------------------------------------------------
C*         4. calculate global annual primary production [g/year]
C             --------- ------ ------ ------- ---------- --------
C     gim=0.006*dphi
C     topro=0.
C     DO 1001 i=1,ie
C     DO 1001 j=jl1,jle
C     topro=topro+gim*dzdl(i,j,1)*prorca(i,j)
C1001 CONTINUE
C      print*,' total production ',topro

C     -----------------------------------------------------------------
C*         5. account for changes in total co2, alkalinity and [po4]
C             due to uptake by poc-/caco3 producing organisms
C             --- -- ------ -- ---------- --------- ---------- -----
      DO 50 j=jl1,jle
      DO 50 i=1,ie
      IF(rwat(i,j).le.0.) GO TO 50

C*         5.1  surface layer c13/c12, c14/c12 total co2 ratios
      pr14pr(i,j)=sco214(i,j,1)/sco212(i,j,1)
      pr13pr(i,j)=sco213(i,j,1)/sco212(i,j,1)

C*         5.2  consumption of total (12c)o2
      sco212(i,j,1)=sco212(i,j,1)
     .  -prorca(i,j)-prcaca(i,j)

C*         5.3  consumption of alkalinity due to ca++ uptake
C               and increase of alkalinity due to nitrate
C               consumption during organic soft tissue production
      alkali(i,j,1)=alkali(i,j,1)
     .  +rno3*prorca(i,j)-two*prcaca(i,j)

C*         5.4  consumption of phosphate
C      Yow!  this is done quietly in subroutine advect!!!
C     phosph(i,j,1)=phosph(i,j,1)-prorca(i,j)

c          x.x  production of o2 -- also quietly done in advect


C*         5.5  consumption of total (14c)o2
      sco214(i,j,1)=sco214(i,j,1)
     .  -pr14pr(i,j)*(plafr14*prorca(i,j)+prcaca(i,j))

C*         5.6  consumption of total (13c)o2
      sco213(i,j,1)=sco213(i,j,1)
     .  -pr13pr(i,j)*(plafr13*prorca(i,j)+prcaca(i,j))

50    CONTINUE

C     -----------------------------------------------------------------
C*         7. vertical distribution of newly produced biogenic
C             caco3 particles and poc in the water column
C             (parts of newly formed matter remaining in the different
C             layers is determined by dmin3, disc3 as defined in
C             SUBROUTINE bioini)
C             ---------- --------- -- ------ ----- -- ------- --------

      DO 60 k=2,ke
      DO 61 j=jl1,jle
      DO 61 i=1,ie
      IF(ddz(i,j,k).le.one) GO TO 61
c       in situ dissolution of sinking calcite

C      calc12(i,j,k)=calc12(i,j,k)+disc3(i,j,k)*tobox
C     1*prcaca(i,j)/ddz(i,j,k)
      sco212(i,j,k)=sco212(i,j,k)+disc3(i,j,k)*tobox
     .  *prcaca(i,j)/ddz(i,j,k)
      alkali(i,j,k)=alkali(i,j,k)+disc3(i,j,k)*tobox
     .  *two*prcaca(i,j)/ddz(i,j,k)
C      calc14(i,j,k)=calc14(i,j,k)+disc3(i,j,k)*tobox
C     **pr14pr(i,j)
C     1*prcaca(i,j)/ddz(i,j,k)
      sco214(i,j,k)=sco214(i,j,k)+disc3(i,j,k)*tobox
     .  *pr14pr(i,j)
     .  *prcaca(i,j)/ddz(i,j,k)
C      calc13(i,j,k)=calc13(i,j,k)+disc3(i,j,k)*tobox
C     **pr13pr(i,j)
C     1*prcaca(i,j)/ddz(i,j,k)
      sco213(i,j,k)=sco213(i,j,k)+disc3(i,j,k)*tobox
     **pr13pr(i,j)
     1*prcaca(i,j)/ddz(i,j,k)

c       in situ remineralization of sinking poc

C      poc12(i,j,k)=poc12(i,j,k)+(tobox/ddz(i,j,k))*
C     1dmin3(i,j,k) *prorca(i,j)
      sco212(i,j,k)=sco212(i,j,k)+(tobox/ddz(i,j,k))
     .  *dmin3(i,j,k) *prorca(i,j)
      phosph(i,j,k)=phosph(i,j,k)+(tobox/ddz(i,j,k))
     .  *dmin3(i,j,k) *prorca(i,j)
      oxygen(i,j,k)=oxygen(i,j,k)-(tobox/ddz(i,j,k))
     .  *dmin3(i,j,k) *prorca(i,j)
     *  *o2ut
      alkali(i,j,k)=alkali(i,j,k)-(tobox/ddz(i,j,k))
     .  *dmin3(i,j,k) *prorca(i,j)
     *  *rno3
C      poc13(i,j,k)=poc13(i,j,k)+(tobox/ddz(i,j,k))*
C     1dmin3(i,j,k)*pr13pr(i,j)*prorca(i,j)*plafr13
      sco213(i,j,k)=sco213(i,j,k)+(tobox/ddz(i,j,k))*
     1  dmin3(i,j,k)*pr13pr(i,j)*prorca(i,j)*plafr13
C      poc14(i,j,k)=poc14(i,j,k)+(tobox/ddz(i,j,k))*
C     1dmin3(i,j,k)*pr14pr(i,j)*prorca(i,j)*plafr14
      sco214(i,j,k)=sco214(i,j,k)+(tobox/ddz(i,j,k))
     1  *dmin3(i,j,k)*pr14pr(i,j)*prorca(i,j)*plafr14

c   previous version -- changed archer 12-11
c      calc12(i,j,k)=calc12(i,j,k)+disc3(i,j,k)*tobox
c     .  *prcaca(i,j)/ddz(i,j,k)
c      calc14(i,j,k)=calc14(i,j,k)+disc3(i,j,k)*tobox
c     .  *pr14pr(i,j)
c     .  *prcaca(i,j)/ddz(i,j,k)
c      calc13(i,j,k)=calc13(i,j,k)+disc3(i,j,k)*tobox
c     .  *pr13pr(i,j)
c     .  *prcaca(i,j)/ddz(i,j,k)
c      poc12(i,j,k)=poc12(i,j,k)+(tobox/ddz(i,j,k))*
c     .  dmin3(i,j,k) *prorca(i,j)
c      poc13(i,j,k)=poc13(i,j,k)+(tobox/ddz(i,j,k))*
c     .  dmin3(i,j,k)*pr13pr(i,j)*prorca(i,j)*plafr13
c      poc14(i,j,k)=poc14(i,j,k)+(tobox/ddz(i,j,k))*
c     .  dmin3(i,j,k)*pr14pr(i,j)*prorca(i,j)*plafr14


61    CONTINUE
60    CONTINUE

C     -----------------------------------------------------------------
C*         8. account for big newly formed particles entering
C             immidiately the sediment pools for organic carbon
C             and caco3
C             --- ------- --- -------- ----- --- ------- ------


      RETURN
6914  FORMAT(i3,7e10.3)
      END


