      SUBROUTINE pools

C**** *pools* - calculates carbon pool sizes

C     c. heinze            mpi hamburg      88/10/06.

C     purpose.
C     --------
C          *pools*  calculates pool sizes of carbon reservoirs
C                   in gigatons (gtc) for checking

C**   interface.
C     ----------
C          *call* *pools*

C     method.
C     -------
C          poll sizes are calculated by integrating the relevant
C     concentrations over the relevant volumes. units for amount
C     of matter (moles) are converted to mass units (grams, resp.
C     gtc=10**15 grams).

C     externals.
C     ----------
C          none.

C     reference.
C     ----------
C          -.

C*     variable      type    purpose.
C      --------      ----    --------

C      *gim*         REAL    conversion factor, distance between two
C                            grid points in latitudinal direction times
C                            molecular weight for carbon in g (division
C                            by two to account for overlapping of grid
C                            point boxes)
C      *gimat*       REAL    conversion factor, distance between two
C                            grid points in latitudinal direction times
C                            molecular weight for carbon in g (division
C                            by two to account for overlapping of grid
C                            point boxes) times conversion factor from
C                            ppm to moles per liter
C      *topro*       REAL    total primary producti[c (g/yr)
C      *rnepro*      REAL    new (or export) production (g/yr)
C      *topoc*       REAL    poc (ocean water) pool (g)
C      *tocalc*      REAL    partic. caco3 (ocean water) pool (g)
C      *toocs*       REAL    organic carbon sediment pool (g)
C      *toccs*       REAL    caco3 carbon sediment pool (g)
C      *tosco2*      REAL    total co2 (dic) ocean water pool (g)
C      *toat12*      REAL    co2 atmosphere water pool (g)

C     -----------------------------------------------------------------
      INCLUDE 'parameter.include'
      INCLUDE 'parameter.sediment.include'
      INCLUDE 'common.horvel'
      INCLUDE 'common.wathic'
      INCLUDE 'common.chemis'
      INCLUDE 'common.biocon'
      INCLUDE 'common.topogr'
      INCLUDE 'common.production'
      INCLUDE 'common.thermo'
      INCLUDE 'common.ctrac'
      INCLUDE 'common.divers'
      INCLUDE 'common.caco3c'
      include 'common.hg'
      INCLUDE 'equivalence.include'
      real tot_layer_hg_inv(ke), tot_layer_area(ke),
     $     tot_layer_volume(ke), tot_layer_hg_flux(ke),
     $     tot_layer_MMHg_inv(ke)

C     -----------------------------------------------------------------
C*         1. set half precision constant(s)
C             ----- ------- ---------- --- --- ---------- --------
      zero=0.
      tenm15=1.e-15

C     -----------------------------------------------------------------
C*         2. conversion factor moles/l in grams per delta z delta
C             lambda (in cm**2) unit area
C             (z: depth in cm, lambda: geogr. longitude)
C             -------------------------------------------- - -----
      gim=0.006*dphi

C     -----------------------------------------------------------------
C*         3. total primary production and new production (g/yr)
C             ----- ------- ---------- --- --- ---------- ------
      topro=zero
      tot_hg_dep = zero
      tot_hg0_degas = zero
      tot_hg_adv_src = zero
      tot_dm_degas = zero
      tot_hg_sed_flux = zero
      tot_layer_hg_inv = zero
      tot_layer_MMHg_inv = zero
      tot_layer_area = zero
      tot_layer_volume = zero
      tot_layer_hg_flux = zero

      DO 1002 j=jl1,jle
      DO 1002 i=1,ie
         if(prorca(i,j) .GT. 0.d0) then
            topro=topro+gim*dzdl(i,j,1)*prorca(i,j) ! gtonc/yr from mol/l yr

            tot_hg_dep = tot_hg_dep
     $           + hg_deposition(i,j) * gim*dzdl(i,j,1)/12.d0 ! mol/yr
            tot_hg0_degas = tot_hg0_degas
     $           + hg_0_degassing(i,j) * gim*dzdl(i,j,1)/12.d0 ! mol/yr
            tot_hg_adv_src = tot_hg_adv_src
     $           + hg_adv_surf_src(i,j) * gim*dzdl(i,j,1)/12.d0 ! mol/yr
            tot_dm_degas = tot_dm_degas
     $           + hg_dm_degassing(i,j) * gim*dzdl(i,j,1)/12.d0 ! mol/yr
            tot_hg_surf_sink_flux = tot_hg_surf_sink_flux
     $           + hg_2p_particle_src(i,j,1)
     $           * gim*dzdl(i,j,1)/12.d0 ! mol/yr

c            write(6,*) i,j,hg_2p_particle_src(i,j,1),
c     $           tot_hg_surf_sink_flux

            tot_hg_sed_flux = tot_hg_sed_flux
     $           + hg_sediment_flux(i,j) ! mol/m2 yr
     $           / 1.d3         ! equiv prorca
     $           / (ddz(i,j,1)/1.d2)
     $           * gim*dzdl(i,j,1)/12.d0 ! mol/yr
            area_box = gim / 12.d0 / 10.d0 ! dy (m)
     $           * dzdl(i,j,1) / 5.d3 ! dx dz / dz (m2)
            do k = 1, 11
               if(ddz(i,j,k) .GT. 1.d0) then
                  tot_layer_area(k) = tot_layer_area(k)
     $                 + area_box
                  tot_layer_volume(k) = tot_layer_volume(k)
     $                 +1.d0
     $                 + area_box * ddz(i,j,k) / 100.d0
                  tot_layer_hg_inv(k) = tot_layer_hg_inv(k)
     $                 + hg_tot(i,j,k) * 1.d3 ! mol / m3
     $                 * ddz(i,j,k)/100.d0 ! mol
     $                 * area_box
                  tot_layer_MMHg_inv(k) = tot_layer_MMHg_inv(k)
     $                 + hg_mm(i,j,k) * 1.d3 ! mol / m3
     $                 * ddz(i,j,k)/100.d0 ! mol
     $                 * area_box
c                  if(k .EQ. 2) then
c                     write(6,"(3i3,3f12.5)") i,j,k,
c     $                 hg_mm(i,j,k)*1.d12,tot_layer_volume(k),
c     $                 tot_layer_MMHg_inv(k) / tot_layer_volume(k)
c     $                    * 1.d12
c                  endif
                  tot_layer_hg_flux(k) = tot_layer_hg_flux(k)
     $                 + hg_2P_sinking_flux(i,j,k)  ! mol/m2 yr
     $                 * area_box 
c                  write(6,*) i,j,k,hg_2P_sinking_flux(i,j,k),
c     $                 tot_layer_hg_flux(k)
               endif
            enddo
         endif
 1002 CONTINUE

      rnepro=zero
      DO 1003 j=jl1,jle
      DO 1003 i=1,ie
         rnepro=rnepro+gim*dzdl(i,j,1)*(prorca(i,j))
c                                      - poccon(i,j)?
 1003 CONTINUE

C     -----------------------------------------------------------------
C*        3a. calcite production g/yr
C             ------- ---------- ----
      toprca=zero
      tocbur = zero
      DO 1112 j=jl1,jle
      DO 1112 i=1,ie
        toprca=toprca+gim*dzdl(i,j,1)*prcaca(i,j)
 1112 CONTINUE



C     -----------------------------------------------------------------
C*         6. total co2 (ocean water, dic) pool (g)
C             ----- --- ------------------ ---- ---
      tosco2=zero
      to13c=0.
      to14c=0.
      talk = zero
      salk = zero
      svol = zero
      t_hg_2p = zero
      t_hg_mm = zero
      t_hg_dm = zero
      t_hg_0 = zero
      t_hg_tot = zero
      DO 1006 k=1,ke
      DO 1006 j=jl1,jle
      DO 1006 i=1,ie
         if(sco212(i,j,k) .GT. 0.d0 ) then
            tosco2 = tosco2
     *        + gim * dzdl(i,j,k)
     *        * sco212(i,j,k)
            to13c = to13c
     *        + gim * dzdl(i,j,k)
     *        * sco213(i,j,k)
            to14c = to14c
     *        + gim * dzdl(i,j,k)
     *        * sco214(i,j,k)
            talk=talk+gim*dzdl(i,j,k)*alkali(i,j,k)

            t_hg_2p = t_hg_2p
     *        + gim * dzdl(i,j,k)
     $        * hg_2p(i,j,k)
            t_hg_mm = t_hg_mm
     *        + gim * dzdl(i,j,k)
     $        * hg_mm(i,j,k)
            t_hg_dm = t_hg_dm
     *        + gim * dzdl(i,j,k)
     $        * hg_dm(i,j,k)
            t_hg_0 = t_hg_0
     *        + gim * dzdl(i,j,k)
     $        * hg_0(i,j,k)
            t_hg_tot = t_hg_tot
     *        + gim * dzdl(i,j,k)
     $        * hg_tot(i,j,k)
         endif

 1006 CONTINUE
      DO j=jl1,jle
         DO i=1,ie
            salk=salk+gim*dzdl(i,j,1)*alkali(i,j,1)
     $           *rwat(i,j)
c            shg = shg+gim/12*dzdl(i,j,1)*hg_2p(i,j,1)
c     $           *rwat(i,j)
            svol=svol+gim*dzdl(i,j,1)*1.*rwat(i,j)
         enddo
      enddo


C     -----------------------------------------------------------------
C*         7. conversion factor ppm in grams per delta lambda (cm)
C             (lambda: geogr. longitude)
C             ------------------------------ --- ----- ------ ----
      gimat=0.006*dphi*0.033

C     -----------------------------------------------------------------
C*         8. atmospheric co2 pool (g)
C             ----------- --- ---- ---
      toat12=zero
      DO 1007 j=jl1,jle
      DO 1007 i=1,ie
      toat12=toat12+gimat*dlll(i,j)*atc12(i,j)
 1007 CONTINUE

C     -----------------------------------------------------------------
C*         9. WRITE pool sizes in gigatons c (/yr)
C             ----- ---- ----- -- -------- - -----
      topro=topro*tenm15

      toprca=toprca*tenm15
      tocbur=tocbur*tenm15
      rnepro=rnepro*tenm15
      topoc=topoc*tenm15
      tocalc=tocalc*tenm15
c      toocs=toocs*tenm15
      toccml=toccml*tenm15
      toccbur=toccbur*tenm15
      toccerod=toccerod*tenm15
      tosco2=tosco2*tenm15
      to13c=to13c*tenm15
      to14c=to14c*tenm15
      talk = talk * tenm15
      t_hg_2p = t_hg_2p / 12.d0  ! moles
      t_hg_mm = t_hg_mm / 12.d0  ! moles
      t_hg_dm = t_hg_dm / 12.d0
      t_hg_0 = t_hg_0 / 12.d0
      t_hg_tot = t_hg_tot / 12.d0 ! moles
      hg_2p_global_sed_flux = hg_2p_global_sed_flux / 12.d0
      salk = salk * tenm15
c      shg = shg * tenm15
      toat12=toat12*tenm15
c      WRITE(6,'('' *pools*'')')
c      write(6,'('' sea surface / deep Hg (mol/l): '',
c     .            2g15.7)') hg_2p(30,40,1)*1.d12,
c     $     hg_2p(30,40,9) * 1.d12

      WRITE(6,'(''                    total Hg (E9 mol): '',
     .            f15.7)')t_hg_tot/ 1.e9
      WRITE(6,'(''                    tot Hg2+ (E9 mol): '',
     .            f15.7)')t_hg_2p/ 1.d9
      WRITE(6,'(''                    tot MMHg (E9 mol): '',
     .            f15.7)')t_hg_mm/1.d9
      WRITE(6,'(''                    tot DMHg (E9 mol): '',
     .            f15.7)')t_hg_dm/1.d9
      WRITE(6,'(''                    tot Hg 0 (E9 mol): '',
     .            f15.7)')t_hg_0/1.d9

      WRITE(6,'(''            Hg deposition (E6 mol/yr): '',
     .            f15.7)')tot_hg_dep/1.d6
      WRITE(6,'(''               Hg 0 degas (E6 mol/yr): '',
     .            f15.7)')tot_hg0_degas/1.d6
      WRITE(6,'(''              Hg DM degas (E6 mol/yr): '',
     .            f15.7)')tot_dm_degas/1.d6
      WRITE(6,'(''        Hg surf sink flux (E6 mol/yr): '',
     .            f15.7)')tot_hg_surf_sink_flux/1.d6

      WRITE(6,'(''          Hg Surf Adv Src (E6 mol/yr): '',
     .            f15.7)')tot_hg_adv_src/1.d6
      WRITE(6,'(''         Hg Net Surf Flux (E6 mol/yr): '',
     .            f15.7)') ( tot_hg_dep
     $                   + tot_hg_surf_sink_flux
c     $                   + tot_hg_adv_src
     $                   + tot_hg0_degas
     $                   + tot_dm_degas ) /1.d6

      WRITE(6,'(''              Hg sed flux (E6 mol/yr): '',
     .            f15.7)')tot_hg_sed_flux/1.d6

      write(6,102) "area", "tot(pM)", "MM(pM)","flux", "lifetime"
 102  format(14x,4a15)
      do k=1, ke
         WRITE(6,101) "Layer ", k, tot_layer_area(k)/1.d9,
     $        tot_layer_hg_inv(k) / tot_layer_volume(k) * 1.d9,
     $        tot_layer_MMHg_inv(k) / tot_layer_volume(k) * 1.d12,
     $        tot_layer_hg_flux(k),
     $        tot_layer_hg_inv(k) / tot_layer_hg_flux(k)
 101     format(A10, i4, 5g15.3)
      enddo

      WRITE(6,'('' total primary production (gtc/yr): '',
     .            f15.7)')topro

      WRITE(6,'(''           new production (gtc/yr): '',
     .            f15.7)')rnepro
      WRITE(6,'(''         caco3 production (gtc/yr): '',
     .            f15.7)')toprca

      return

      WRITE(6,'(''  total co2 (dic) ocean pool (gtc): '',
     .            f15.7)')tosco2
      WRITE(6,'(''  total 13c (dic) ocean pool (gtc): '',
     .            f15.7)')to13c
      WRITE(6,'(''  total 14c (dic) ocean pool (gtc): '',
     .            f15.7)')to14c
      WRITE(6,'(''     alk ocean pool (C gtc equiv.): '',
     .            f15.7)')talk
      WRITE(6,'(''        sea surf alk conc (mol/l): '',
     .            f15.7)')salk*1e15/svol
      WRITE(6,'(''        atmospheric co2 pool (gtc): '',
     .            f15.7)')toat12
      WRITE(6,'(''       total system co2 pool (gtc): '',
     .            f15.7)')   toccml
     *                     + toccbur
     *                     + tosco2
     *                     + toat12
      WRITE(6,'(''   total system alk pool (gtc eqv): '',
     .            f15.7)')   talk
     *                     + 2 * toccml
     *                     + 2 * toccbur
      RETURN
      END




      SUBROUTINE calc_no_caco3_clay(z,kmax,clay_gcm2)

      parameter( kmax_max = 20)
      real z(kmax),calgg(kmax_max),pore(kmax_max)

      do i=1, kmax
         calgg(i) = 0.
      enddo

      call set_pore(calgg,z,pore,
     $     kmax,1,1,1)

      clay_gcm2 = 0.
      do i=2, kmax
         clay_gcm2 = clay_gcm2
     $        + (z(i)-z(i-1)) * (1-pore(i)) * 2.5
c                        cm3     cm3 solid   g solid
      enddo
      return
      end

